@@ -188,6 +188,10 @@ def create_excel_string_repr(data_set, ordered_class_ws_mappings=None):
     wb = create_excel_wb_from_class_mappings(data_set, ordered_class_ws_mappings=None)
     return save_virtual_workbook(wb)
 
+def create_excel_string_repr_for_tables(data_set, tables):
+    wb = create_excel_wb_for_tables(data_set, tables)
+    return save_virtual_workbook(wb)
+
 
 def create_example_data_set_from_excel(data_set, file_name_with_path):  # Deprecated! Todo: Replace with load_data_from_excel_file_on_disk. Shouldn't be creating data sets in here.
     wb = xlrd.open_workbook(file_name_with_path)
