@@ -95,8 +95,6 @@ class ExecuteFunction(Widget):
         :rtype: None
 
         - Use :func:`tropofy.app.AppDataSet.send_progress_message` to post messages to the GUI.
-        - Use :func:`tropofy.app.AppDataSet.user_is_previewing_app` to determine if a user is using your app with a preview subscription, i.e. they have not paid
-        - Use :func:`tropofy.app.AppDataSet.send_preview_mode_debug_window_message` to send messages to the debug window when your app is being previewed to aid in debugging
 
         The following example shows the data_set being queried to determine if a user is on a paid subscription before solving
 
