@@ -119,12 +119,11 @@ class ExecuteSolverFunction(ExecuteFunction):
         return "Solve Facility Location Problem"
 
     def execute_function(self, data_set):
-        if data_set.user_is_previewing_app() and len(data_set.query(Shop).all()) > 200:
+        if len(data_set.query(Shop).all()) > 200:
             data_set.send_progress_message("You can only solve problems with 200 shops of fewer using the free version of this app")
         else:
             formulate_and_solve_facility_location_problem(data_set)
 
-
 class PlantSizePieChart(Chart):
     def get_chart_type(self, data_set):
         return Chart.PIECHART
